==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/gods/dialogs_pl.lua <==

dialogId("lod-v-silenost0", "font_big", "I have a suspicion that we are about to discover something terrible.")
dialogStr("Mam przeczucie, że za chwilę odkryjemy coś przerażającego.")


dialogId("lod-v-silenost1", "font_big", "I always knew that: the gods must be mad.")
dialogStr("Zawsze mówiłem, że bogowie muszą być szaleni.")


dialogId("lod-v-silenost2", "font_big", "God is mad and the whole world is his plaything.")
dialogStr("Bóg jest szalony, a cały świat to jego plac zabaw.")


dialogId("lod-m-pravda0", "font_small", "I think that you are right.")
dialogStr("Chyba masz rację.")


dialogId("lod-m-pravda1", "font_small", "I am afraid that you are right.")
dialogStr("Obawiam się, że masz rację.")


dialogId("lod-m-pravda2", "font_small", "Yes, it is shocking.")
dialogStr("Tak. To szokujące.")


dialogId("lod-m-costim", "font_small", "What are we to do about it?")
dialogStr("I co z tym zrobimy?")


dialogId("lod-v-internovat", "font_big", "We can`t leave it this way. We must incarcerate them.")
dialogStr("Nie możemy tego tak zostawić. Musimy ich internować.")


dialogId("lod-m-co", "font_small", "What must we do?")
dialogStr("Co zrobić?")


dialogId("lod-v-cvok", "font_big", "Put them into the mad... I mean into the detainment facility of FDTO.")
dialogStr("Zamknąć w waria... znaczy w zakładzie poprawczym FDTO.")


dialogId("lod-m-oba", "font_small", "You are right. Shall we take both of them?")
dialogStr("Masz rację. Bierzemy ich obu?")


dialogId("lod-v-golf", "font_big", "Of course. If we leave one of them here, any mad idea could occur to him. He could try to start playing golf, for example.")
dialogStr("Oczywiście. Jeśli zostawimy tu jednego, różne rzeczy mogą mu przyjść do głowy. Mógłby, na ten przykład, zacząć grać w golfa.")


dialogId("lod-m-jednoho", "font_small", "Hardly with this club. I think we should be happy if we manage to get one. The other one will be harmless then.")
dialogStr("Ciężko by mu było tym kijkiem. Myślę, że zadowolimy się jednym. Ten drugi już nie będzie niebezpieczny.")


dialogId("lod-v-koho", "font_big", "Well. Which one?")
dialogStr("Dobra. To którego?")


dialogId("lod-m-zluty", "font_small", "The yellow one.")
dialogStr("Tego żółtego.")


dialogId("lod-m-modry", "font_small", "The blue one.")
dialogStr("Tego niebieskiego.")


dialogId("lod-v-zluty", "font_big", "That yellow one.")
dialogStr("Tego żółtego.")


dialogId("lod-v-modry", "font_big", "That blue one.")
dialogStr("Tego niebieskiego.")


dialogId("lod-m-hrac", "font_small", "We will leave this to the player.")
dialogStr("Niech gracz zdecyduje.")


dialogId("lod-v-hrac", "font_big", "We shall leave this to the player.")
dialogStr("Niech gracz zdecyduje.")


dialogId("lod-v-hul", "font_big", "Look at that club: something terrible happened to it.")
dialogStr("Spójrz na ten kij, coś strasznego musiało mu się przytrafić.")


dialogId("lod-m-ozizlana", "font_small", "A pld probably sucked upon it.")
dialogStr("Pewnie pld go possał.")


dialogId("lod-v-hravost", "font_big", "Mother was right. Abnormal playfulness is the root of all evil.")
dialogStr("Mama miała rację: uzależnienie od gier jest źródłem wszelkiego zła.")


dialogId("lod-m-palka", "font_small", "That`s true. It would be much easier if that table tennis bat was somewhere else.")
dialogStr("To prawda. Byłoby dużo prościej, gdyby ta paletka od ping-ponga była gdzie indziej.")


dialogId("lod-v-micky", "font_big", "By the way, did you notice that the real golf ball is in the upper left corner while that thing in the lower right corner is a cricket ball?")
dialogStr("Tak na marginesie, zauważyłaś, że prawdziwa piłka golfowa jest na górze po lewej, a ta piłka po prawej na dole jest do krykieta?")


dialogId("lod-m-vyznam", "font_small", "Is there some hidden symbolism?")
dialogStr("Myślisz, że to ma jakieś ukryte znaczenie?")


dialogId("lod-v-kdovi", "font_big", "Who knows.")
dialogStr("Kto wie?")


dialogId("lod-m-micek", "font_small", "I thought it was a table tennis ball up there.")
dialogStr("Myślałam, że ta na górze po prawej to piłka do ping-ponga.")


dialogId("lod-v-rozliseni", "font_big", "It`s hard to say with this screen resolution.")
dialogStr("Trudno powiedzieć przy tej rozdzielczości.")


dialogId("lod-m-bohove", "font_small", "This time our goal is to get out one of those gods.")
dialogStr("Tym razem naszym zadaniem jest wydostanie stąd jednego z tych bogów.")


dialogId("b1-voda1", "font_yellow", "Miss!")
dialogStr("Pudło!")


dialogId("b1-voda2", "font_yellow", "Miss!")
dialogStr("Pudło!")


dialogId("b1-voda3", "font_yellow", "Miss!")
dialogStr("Pudło!")


dialogId("b1-voda4", "font_yellow", "Miss!")
dialogStr("Pudło!")


dialogId("b1-voda5", "font_yellow", "Miss!")
dialogStr("Pudło!")


dialogId("b1-zasah1", "font_yellow", "Hit!")
dialogStr("Trafiony!")


dialogId("b1-zasah2", "font_yellow", "Hit!")
dialogStr("Trafiony!")


dialogId("b1-zasah3", "font_yellow", "Hit!")
dialogStr("Trafiony!")


dialogId("b1-zasah4", "font_yellow", "Hit!")
dialogStr("Trafiony!")


dialogId("b1-potop1", "font_yellow", "Sank!")
dialogStr("Trafiony, zatopiony!")


dialogId("b1-potop2", "font_yellow", "Sank!")
dialogStr("Trafiony, zatopiony!")


dialogId("b1-potop3", "font_yellow", "Sank!")
dialogStr("Trafiony, zatopiony!")


dialogId("b1-vyhral", "font_yellow", "I won, you sissy!!!")
dialogStr("Wygrałem, cieniasie!!!")


dialogId("b1-zacinam", "font_yellow", "I start!")
dialogStr("Ja zaczynam!")


dialogId("b1-dobre", "font_yellow", "Well!")
dialogStr("Dobrze!")


dialogId("b1-znovu", "font_yellow", "Shall we play another one?")
dialogStr("Gramy od nowa?")


dialogId("b1-nepodvadim", "font_yellow", "I don`t cheat.")
dialogStr("Ja nie oszukuję!!!")


dialogId("b1-spletl", "font_yellow", "It was a mistake, probably...")
dialogStr("Coś mi się pomyliło...")


dialogId("b2-voda1", "font_cyan", "Miss!")
dialogStr("Pudło!")


dialogId("b2-voda2", "font_cyan", "Miss!")
dialogStr("Pudło!")


dialogId("b2-voda3", "font_cyan", "Miss!")
dialogStr("Pudło!")


dialogId("b2-voda4", "font_cyan", "Miss!")
dialogStr("Pudło!")


dialogId("b2-voda5", "font_cyan", "Miss!")
dialogStr("Pudło!")


dialogId("b2-zasah1", "font_cyan", "Hit!")
dialogStr("Trafiony!")


dialogId("b2-zasah2", "font_cyan", "Hit!")
dialogStr("Trafiony!")


dialogId("b2-zasah3", "font_cyan", "Hit!")
dialogStr("Trafiony!")


dialogId("b2-zasah4", "font_cyan", "Hit!")
dialogStr("Trafiony!")


dialogId("b2-potop1", "font_cyan", "Sank!")
dialogStr("Trafiony, zatopiony!")


dialogId("b2-potop2", "font_cyan", "Sank!")
dialogStr("Trafiony, zatopiony!")


dialogId("b2-potop3", "font_cyan", "Sank!")
dialogStr("Trafiony, zatopiony!")


dialogId("b2-vyhral", "font_cyan", "He, he, he... I won!")
dialogStr("Ha ha ha... wygrałem!")


dialogId("b2-dobre", "font_cyan", "Well!")
dialogStr("Dobrze!")


dialogId("b2-znovu", "font_cyan", "Shall we try it again?")
dialogStr("Zagramy jeszcze raz?")


dialogId("b2-rikal1", "font_cyan", "You already tried this!")
dialogStr("To już było!")


dialogId("b2-rikal2", "font_cyan", "You already said that!")
dialogStr("Już tu strzelałeś!")


dialogId("b2-nemuze", "font_cyan", "It can`t be a miss on this space.")
dialogStr("Niemożliwe, żeby tu było pudło!")


dialogId("b2-podvadis", "font_cyan", "You cheat!!!")
dialogStr("Oszukujesz!!!")


dialogId("b2-spatne", "font_cyan", "I have tried that - and you said 'miss`!")
dialogStr("Już tu strzelałem... i powiedziałeś 'pudło'!")


dialogId("b1-1", "", "")
dialogStr("")


dialogId("b1-2", "", "")
dialogStr("")


dialogId("b1-3", "", "")
dialogStr("")


dialogId("b1-4", "", "")
dialogStr("")


dialogId("b1-5", "", "")
dialogStr("")


dialogId("b1-6", "", "")
dialogStr("")


dialogId("b1-7", "", "")
dialogStr("")


dialogId("b1-8", "", "")
dialogStr("")


dialogId("b1-9", "", "")
dialogStr("")


dialogId("b1-10", "", "")
dialogStr("")


dialogId("b1-a", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-b", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-c", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-d", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-e", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-f", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-g", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-h", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-i", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-j", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b2-1", "", "")
dialogStr("")


dialogId("b2-2", "", "")
dialogStr("")


dialogId("b2-3", "", "")
dialogStr("")


dialogId("b2-4", "", "")
dialogStr("")


dialogId("b2-5", "", "")
dialogStr("")


dialogId("b2-6", "", "")
dialogStr("")


dialogId("b2-7", "", "")
dialogStr("")


dialogId("b2-8", "", "")
dialogStr("")


dialogId("b2-9", "", "")
dialogStr("")


dialogId("b2-10", "", "")
dialogStr("")


dialogId("b2-a", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-b", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-c", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-d", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-e", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-f", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-g", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-h", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-i", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-j", "font_cyan", "%1.")
dialogStr("%1.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/gods/dialogs_pl.lua <==

dialogId("lod-v-silenost0", "font_big", "I have a suspicion that we are about to discover something terrible.")
dialogStr("Mam przeczucie, że za chwilę odkryjemy coś przerażającego.")


dialogId("lod-v-silenost1", "font_big", "I always knew that: the gods must be mad.")
dialogStr("Zawsze mówiłem, że bogowie muszą być szaleni.")


dialogId("lod-v-silenost2", "font_big", "God is mad and the whole world is his plaything.")
dialogStr("Bóg jest szalony, a cały świat to jego plac zabaw.")


dialogId("lod-m-pravda0", "font_small", "I think that you are right.")
dialogStr("Chyba masz rację.")


dialogId("lod-m-pravda1", "font_small", "I am afraid that you are right.")
dialogStr("Obawiam się, że masz rację.")


dialogId("lod-m-pravda2", "font_small", "Yes, it is shocking.")
dialogStr("Tak. To szokujące.")


dialogId("lod-m-costim", "font_small", "What are we to do about it?")
dialogStr("I co z tym zrobimy?")


dialogId("lod-v-internovat", "font_big", "We can’t leave it this way. We must incarcerate them.")
dialogStr("Nie możemy tego tak zostawić. Musimy ich internować.")


dialogId("lod-m-co", "font_small", "What must we do?")
dialogStr("Co zrobić?")


dialogId("lod-v-cvok", "font_big", "Put them into the mad... I mean into the detainment facility of FDTO.")
dialogStr("Zamknąć w waria... znaczy w zakładzie poprawczym FDTO.")


dialogId("lod-m-oba", "font_small", "You are right. Shall we take both of them?")
dialogStr("Masz rację. Bierzemy ich obu?")


dialogId("lod-v-golf", "font_big", "Of course. If we leave one of them here, any mad idea could occur to him. He could try to start playing golf, for example.")
dialogStr("Oczywiście. Jeśli zostawimy tu jednego, różne rzeczy mogą mu przyjść do głowy. Mógłby, na ten przykład, zacząć grać w golfa.")


dialogId("lod-m-jednoho", "font_small", "Hardly with this club. I think we should be happy if we manage to get one. The other one will be harmless then.")
dialogStr("Ciężko by mu było tym kijkiem. Myślę, że zadowolimy się jednym. Ten drugi już nie będzie niebezpieczny.")


dialogId("lod-v-koho", "font_big", "Well. Which one?")
dialogStr("Dobra. To którego?")


dialogId("lod-m-zluty", "font_small", "The yellow one.")
dialogStr("Tego żółtego.")


dialogId("lod-m-modry", "font_small", "The blue one.")
dialogStr("Tego niebieskiego.")


dialogId("lod-v-zluty", "font_big", "That yellow one.")
dialogStr("Tego żółtego.")


dialogId("lod-v-modry", "font_big", "That blue one.")
dialogStr("Tego niebieskiego.")


dialogId("lod-m-hrac", "font_small", "We will leave this to the player.")
dialogStr("Niech gracz zdecyduje.")


dialogId("lod-v-hrac", "font_big", "We shall leave this to the player.")
dialogStr("Niech gracz zdecyduje.")


dialogId("lod-v-hul", "font_big", "Look at that club: something terrible happened to it.")
dialogStr("Spójrz na ten kij, coś strasznego musiało mu się przytrafić.")


dialogId("lod-m-ozizlana", "font_small", "A pld probably sucked upon it.")
dialogStr("Pewnie pld go possał.")


dialogId("lod-v-hravost", "font_big", "Mother was right. Abnormal playfulness is the root of all evil.")
dialogStr("Mama miała rację: uzależnienie od gier jest źródłem wszelkiego zła.")


dialogId("lod-m-palka", "font_small", "That’s true. It would be much easier if that table tennis bat was somewhere else.")
dialogStr("To prawda. Byłoby dużo prościej, gdyby ta paletka od ping-ponga była gdzie indziej.")


dialogId("lod-v-micky", "font_big", "By the way, did you notice that the real golf ball is in the upper left corner while that thing in the lower right corner is a cricket ball?")
dialogStr("Tak na marginesie, zauważyłaś, że prawdziwa piłka golfowa jest na górze po lewej, a ta piłka po prawej na dole jest do krykieta?")


dialogId("lod-m-vyznam", "font_small", "Is there some hidden symbolism?")
dialogStr("Myślisz, że to ma jakieś ukryte znaczenie?")


dialogId("lod-v-kdovi", "font_big", "Who knows.")
dialogStr("Kto wie?")


dialogId("lod-m-micek", "font_small", "I thought it was a table tennis ball up there.")
dialogStr("Myślałam, że ta na górze po prawej to piłka do ping-ponga.")


dialogId("lod-v-rozliseni", "font_big", "It’s hard to say with this screen resolution.")
dialogStr("Trudno powiedzieć przy tej rozdzielczości.")


dialogId("lod-m-bohove", "font_small", "This time our goal is to get out one of those gods.")
dialogStr("Tym razem naszym zadaniem jest wydostanie stąd jednego z tych bogów.")


dialogId("b1-voda1", "font_yellow", "Miss!")
dialogStr("Pudło!")


dialogId("b1-voda2", "font_yellow", "Miss!")
dialogStr("Pudło!")


dialogId("b1-voda3", "font_yellow", "Miss!")
dialogStr("Pudło!")


dialogId("b1-voda4", "font_yellow", "Miss!")
dialogStr("Pudło!")


dialogId("b1-voda5", "font_yellow", "Miss!")
dialogStr("Pudło!")


dialogId("b1-zasah1", "font_yellow", "Hit!")
dialogStr("Trafiony!")


dialogId("b1-zasah2", "font_yellow", "Hit!")
dialogStr("Trafiony!")


dialogId("b1-zasah3", "font_yellow", "Hit!")
dialogStr("Trafiony!")


dialogId("b1-zasah4", "font_yellow", "Hit!")
dialogStr("Trafiony!")


dialogId("b1-potop1", "font_yellow", "Sank!")
dialogStr("Trafiony, zatopiony!")


dialogId("b1-potop2", "font_yellow", "Sank!")
dialogStr("Trafiony, zatopiony!")


dialogId("b1-potop3", "font_yellow", "Sank!")
dialogStr("Trafiony, zatopiony!")


dialogId("b1-vyhral", "font_yellow", "I won, you sissy!!!")
dialogStr("Wygrałem, cieniasie!!!")


dialogId("b1-zacinam", "font_yellow", "I start!")
dialogStr("Ja zaczynam!")


dialogId("b1-dobre", "font_yellow", "Well!")
dialogStr("Dobrze!")


dialogId("b1-znovu", "font_yellow", "Shall we play another one?")
dialogStr("Gramy od nowa?")


dialogId("b1-nepodvadim", "font_yellow", "I don’t cheat.")
dialogStr("Ja nie oszukuję!!!")


dialogId("b1-spletl", "font_yellow", "It was a mistake, probably...")
dialogStr("Coś mi się pomyliło...")


dialogId("b2-voda1", "font_cyan", "Miss!")
dialogStr("Pudło!")


dialogId("b2-voda2", "font_cyan", "Miss!")
dialogStr("Pudło!")


dialogId("b2-voda3", "font_cyan", "Miss!")
dialogStr("Pudło!")


dialogId("b2-voda4", "font_cyan", "Miss!")
dialogStr("Pudło!")


dialogId("b2-voda5", "font_cyan", "Miss!")
dialogStr("Pudło!")


dialogId("b2-zasah1", "font_cyan", "Hit!")
dialogStr("Trafiony!")


dialogId("b2-zasah2", "font_cyan", "Hit!")
dialogStr("Trafiony!")


dialogId("b2-zasah3", "font_cyan", "Hit!")
dialogStr("Trafiony!")


dialogId("b2-zasah4", "font_cyan", "Hit!")
dialogStr("Trafiony!")


dialogId("b2-potop1", "font_cyan", "Sank!")
dialogStr("Trafiony, zatopiony!")


dialogId("b2-potop2", "font_cyan", "Sank!")
dialogStr("Trafiony, zatopiony!")


dialogId("b2-potop3", "font_cyan", "Sank!")
dialogStr("Trafiony, zatopiony!")


dialogId("b2-vyhral", "font_cyan", "He, he, he... I won!")
dialogStr("Ha ha ha... wygrałem!")


dialogId("b2-dobre", "font_cyan", "Well!")
dialogStr("Dobrze!")


dialogId("b2-znovu", "font_cyan", "Shall we try it again?")
dialogStr("Zagramy jeszcze raz?")


dialogId("b2-rikal1", "font_cyan", "You already tried this!")
dialogStr("To już było!")


dialogId("b2-rikal2", "font_cyan", "You already said that!")
dialogStr("Już tu strzelałeś!")


dialogId("b2-nemuze", "font_cyan", "It can’t be a miss on this space.")
dialogStr("Niemożliwe, żeby tu było pudło!")


dialogId("b2-podvadis", "font_cyan", "You cheat!!!")
dialogStr("Oszukujesz!!!")


dialogId("b2-spatne", "font_cyan", "I have tried that - and you said 'miss’!")
dialogStr("Już tu strzelałem... i powiedziałeś 'pudło'!")


dialogId("b1-1", "", "")
dialogStr("")


dialogId("b1-2", "", "")
dialogStr("")


dialogId("b1-3", "", "")
dialogStr("")


dialogId("b1-4", "", "")
dialogStr("")


dialogId("b1-5", "", "")
dialogStr("")


dialogId("b1-6", "", "")
dialogStr("")


dialogId("b1-7", "", "")
dialogStr("")


dialogId("b1-8", "", "")
dialogStr("")


dialogId("b1-9", "", "")
dialogStr("")


dialogId("b1-10", "", "")
dialogStr("")


dialogId("b1-a", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-b", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-c", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-d", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-e", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-f", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-g", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-h", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-i", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-j", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b2-1", "", "")
dialogStr("")


dialogId("b2-2", "", "")
dialogStr("")


dialogId("b2-3", "", "")
dialogStr("")


dialogId("b2-4", "", "")
dialogStr("")


dialogId("b2-5", "", "")
dialogStr("")


dialogId("b2-6", "", "")
dialogStr("")


dialogId("b2-7", "", "")
dialogStr("")


dialogId("b2-8", "", "")
dialogStr("")


dialogId("b2-9", "", "")
dialogStr("")


dialogId("b2-10", "", "")
dialogStr("")


dialogId("b2-a", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-b", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-c", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-d", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-e", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-f", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-g", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-h", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-i", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-j", "font_cyan", "%1.")
dialogStr("%1.")
